AsyncAdapter

Struct AsyncAdapter 

pub struct AsyncAdapter;
Available on crate feature async only.
Namespace for async Adapter operations.

Examples

use foundation_models::async_api::AsyncAdapter;

pollster::block_on(async {
    let ids = AsyncAdapter::compatibility("com.example.MyAdapter")?.await?;
    println!("compatible: {ids:?}");
    Ok::<(), Box<dyn std::error::Error>>(())
})

Implementations

Source

impl AsyncAdapter

pub fn from_name(name: &str) -> Result<AdapterInitFuture, FMError>

Async version of SystemLanguageModel.Adapter init(name:).

Loads the named adapter asynchronously, returning a ready-to-use Adapter handle.

Errors

Returns an FMError::AdapterInvalidName if the adapter is not found or the name contains a NUL byte.

pub fn compatibility(name: &str) -> Result<AdapterCompatibilityFuture, FMError>

Async version of SystemLanguageModel.Adapter.compatibility(for:).

Returns the list of compatible adapter identifiers for the given logical adapter name.

Errors

Returns an FMError::AdapterCompatibleNotFound on failure.