GenerationOptions

Struct GenerationOptions 

pub struct GenerationOptions { /* private fields */ }
Generation knobs. All fields are optional; unset fields keep the model’s defaults.

Implementations

Source

impl GenerationOptions

pub const fn new() -> Self

Create options with all fields set to their defaults.

pub const fn with_temperature(self, temperature: f64) -> Self

Sampling temperature; higher values produce more varied output. FoundationModels accepts values in 0.0..=2.0.

pub const fn with_maximum_response_tokens(self, tokens: u32) -> Self

Hard cap on the number of tokens the model may emit.

pub const fn with_sampling(self, mode: SamplingMode) -> Self

Override the sampling strategy.

pub const fn with_sampling_seed(self, seed: u64) -> Self

Use a deterministic random seed for non-greedy sampling.

pub const fn temperature(self) -> Option<f64>

Sampling temperature, if explicitly set.

pub const fn maximum_response_tokens(self) -> Option<u32>

The explicit token cap, if any.

pub const fn sampling(self) -> SamplingMode

The configured sampling strategy.

pub const fn sampling_seed(self) -> Option<u64>

The deterministic random seed for top-k / top-p sampling.