ResponseFormat

Struct ResponseFormat 

pub struct ResponseFormat { /* private fields */ }
A transcript response format.

Implementations

Source

impl ResponseFormat

pub fn json_schema(schema: GenerationSchema) -> Self

Create a response format from a generation schema.

pub fn generating<T>() -> Result<Self, FMError>
where T: Generable,

Create a response format from a Generable Rust type.

Errors

Returns an FMError if the type cannot produce a generation schema.

pub fn with_name(self, name: impl Into<String>) -> Self

Attach an explicit display name.

pub fn name(&self) -> String

Display name FoundationModels associates with this response format.

pub const fn schema(&self) -> &GenerationSchema

The underlying schema.